A function that takes in raw griPASTA data and behaves similar to a loop - continuously promts user exclude artifacts until no artifacts are present. If artifact is present, user is promted to enter starting and ending x coordinate of the artefact, and artefact is deleted.
griPASTA(data, usePlotly = TRUE)Raw griPASTA data loaded with function loadgriPASTA or manually.
TRUE or FALSE argument. If set to TRUE, plotly will be used to render plot for each animal.
Returns measurements for each animal