Learn R Programming

ratPASTA (version 0.2.1)

summariseStartle: Summarise Startle

Description

Returns a mathematical summary of the startle data. Returned list with two data frames. First contains calculated median, interquartile range, mean and standard deviation for values pertaining to the period of the pulse and in between pulses. The second contains the results of the desired statistical test, by default Wilcox is used. User can specify which test will be used with method argument.

Usage

summariseStartle(df, method = "wilcox.test")

Arguments

df

A dataframe returned by loadStartleData function.

method

A parameter defining what type of statistical testing will be used.

Value

A mathematical summary in a list.

Examples

Run this code
# NOT RUN {
# Load example data
df <- ratpasta_demo

# running examples
summariseStartle(df)
# }

Run the code above in your browser using DataLab